Fixed

Struct Fixed 

pub struct Fixed<const N: usize>(pub usize);
Marker for fixed length.

A fixed length pads the input to the desired length. The deserialization will always return the fixed value and the full data.

Tuple Fields

0: usize