pub struct Fixed<const N: usize>(pub usize);Expand description
Marker for fixed length.
A fixed length pads the input to the desired length. The deserialization will always return the fixed value and the full data.
Tuple Fields
0: usizeTrait Implementations